/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.adexchangebuyer.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * A creative and its classification data.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Ad Exchange Buyer API. For a detailed explanation
 * see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Creative extends GenericJson {

  /**
   * The HTML snippet that displays the ad when inserted in the web page. If set, videoURL should
   * not be set.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("HTMLSnippet")
  private String hTMLSnippet;

  /**
   * Account id.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer accountId;

  /**
   * Detected advertiser id, if any. Read-only. This field should not be set in requests.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private java.util.List<Long> advertiserId;

  /**
   * The name of the company being advertised in the creative.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String advertiserName;

  /**
   * The agency id for this creative.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long agencyId;

  /**
   * All attributes for the ads that may be shown from this snippet.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Integer> attribute;

  /**
   * A buyer-specific id identifying the creative in this ad.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String buyerCreativeId;

  /**
   * The set of destination urls for the snippet.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> clickThroughUrl;

  /**
   * The reasons for disapproval, if any. Note that not all disapproval reasons may be categorized,
   * so it is possible for the creative to have a status of DISAPPROVED with an empty list for
   * disapproval_reasons. In this case, please reach out to your TAM to help debug the issue. Read-
   * only. This field should not be set in requests.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<DisapprovalReasons> disapprovalReasons;

  static {
    // hack to force ProGuard to consider DisapprovalReasons used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(DisapprovalReasons.class);
  }

  /**
   * Ad height.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer height;

  /**
   * Resource type.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Detected product categories, if any. Read-only. This field should not be set in requests.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Integer> productCategories;

  /**
   * Detected sensitive categories, if any. Read-only. This field should not be set in requests.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Integer> sensitiveCategories;

  /**
   * Creative serving status. Read-only. This field should not be set in requests.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String status;

  /**
   * All vendor types for the ads that may be shown from this snippet.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Integer> vendorType;

  /**
   * The url to fetch a video ad. If set, HTMLSnippet should not be set.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String videoURL;

  /**
   * Ad width.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer width;

  /**
   * The HTML snippet that displays the ad when inserted in the web page. If set, videoURL should
   * not be set.
   * The value returned may be {@code null}.
   */
  public String getHTMLSnippet() {
    return hTMLSnippet;
  }

  /**
   * The HTML snippet that displays the ad when inserted in the web page. If set, videoURL should
   * not be set.
   * The value set may be {@code null}.
   */
  public Creative setHTMLSnippet(String hTMLSnippet) {
    this.hTMLSnippet = hTMLSnippet;
    return this;
  }

  /**
   * Account id.
   * The value returned may be {@code null}.
   */
  public Integer getAccountId() {
    return accountId;
  }

  /**
   * Account id.
   * The value set may be {@code null}.
   */
  public Creative setAccountId(Integer accountId) {
    this.accountId = accountId;
    return this;
  }

  /**
   * Detected advertiser id, if any. Read-only. This field should not be set in requests.
   * The value returned may be {@code null}.
   */
  public java.util.List<Long> getAdvertiserId() {
    return advertiserId;
  }

  /**
   * Detected advertiser id, if any. Read-only. This field should not be set in requests.
   * The value set may be {@code null}.
   */
  public Creative setAdvertiserId(java.util.List<Long> advertiserId) {
    this.advertiserId = advertiserId;
    return this;
  }

  /**
   * The name of the company being advertised in the creative.
   * The value returned may be {@code null}.
   */
  public String getAdvertiserName() {
    return advertiserName;
  }

  /**
   * The name of the company being advertised in the creative.
   * The value set may be {@code null}.
   */
  public Creative setAdvertiserName(String advertiserName) {
    this.advertiserName = advertiserName;
    return this;
  }

  /**
   * The agency id for this creative.
   * The value returned may be {@code null}.
   */
  public Long getAgencyId() {
    return agencyId;
  }

  /**
   * The agency id for this creative.
   * The value set may be {@code null}.
   */
  public Creative setAgencyId(Long agencyId) {
    this.agencyId = agencyId;
    return this;
  }

  /**
   * All attributes for the ads that may be shown from this snippet.
   * The value returned may be {@code null}.
   */
  public java.util.List<Integer> getAttribute() {
    return attribute;
  }

  /**
   * All attributes for the ads that may be shown from this snippet.
   * The value set may be {@code null}.
   */
  public Creative setAttribute(java.util.List<Integer> attribute) {
    this.attribute = attribute;
    return this;
  }

  /**
   * A buyer-specific id identifying the creative in this ad.
   * The value returned may be {@code null}.
   */
  public String getBuyerCreativeId() {
    return buyerCreativeId;
  }

  /**
   * A buyer-specific id identifying the creative in this ad.
   * The value set may be {@code null}.
   */
  public Creative setBuyerCreativeId(String buyerCreativeId) {
    this.buyerCreativeId = buyerCreativeId;
    return this;
  }

  /**
   * The set of destination urls for the snippet.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getClickThroughUrl() {
    return clickThroughUrl;
  }

  /**
   * The set of destination urls for the snippet.
   * The value set may be {@code null}.
   */
  public Creative setClickThroughUrl(java.util.List<String> clickThroughUrl) {
    this.clickThroughUrl = clickThroughUrl;
    return this;
  }

  /**
   * The reasons for disapproval, if any. Note that not all disapproval reasons may be categorized,
   * so it is possible for the creative to have a status of DISAPPROVED with an empty list for
   * disapproval_reasons. In this case, please reach out to your TAM to help debug the issue. Read-
   * only. This field should not be set in requests.
   * The value returned may be {@code null}.
   */
  public java.util.List<DisapprovalReasons> getDisapprovalReasons() {
    return disapprovalReasons;
  }

  /**
   * The reasons for disapproval, if any. Note that not all disapproval reasons may be categorized,
   * so it is possible for the creative to have a status of DISAPPROVED with an empty list for
   * disapproval_reasons. In this case, please reach out to your TAM to help debug the issue. Read-
   * only. This field should not be set in requests.
   * The value set may be {@code null}.
   */
  public Creative setDisapprovalReasons(java.util.List<DisapprovalReasons> disapprovalReasons) {
    this.disapprovalReasons = disapprovalReasons;
    return this;
  }

  /**
   * Ad height.
   * The value returned may be {@code null}.
   */
  public Integer getHeight() {
    return height;
  }

  /**
   * Ad height.
   * The value set may be {@code null}.
   */
  public Creative setHeight(Integer height) {
    this.height = height;
    return this;
  }

  /**
   * Resource type.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Resource type.
   * The value set may be {@code null}.
   */
  public Creative setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Detected product categories, if any. Read-only. This field should not be set in requests.
   * The value returned may be {@code null}.
   */
  public java.util.List<Integer> getProductCategories() {
    return productCategories;
  }

  /**
   * Detected product categories, if any. Read-only. This field should not be set in requests.
   * The value set may be {@code null}.
   */
  public Creative setProductCategories(java.util.List<Integer> productCategories) {
    this.productCategories = productCategories;
    return this;
  }

  /**
   * Detected sensitive categories, if any. Read-only. This field should not be set in requests.
   * The value returned may be {@code null}.
   */
  public java.util.List<Integer> getSensitiveCategories() {
    return sensitiveCategories;
  }

  /**
   * Detected sensitive categories, if any. Read-only. This field should not be set in requests.
   * The value set may be {@code null}.
   */
  public Creative setSensitiveCategories(java.util.List<Integer> sensitiveCategories) {
    this.sensitiveCategories = sensitiveCategories;
    return this;
  }

  /**
   * Creative serving status. Read-only. This field should not be set in requests.
   * The value returned may be {@code null}.
   */
  public String getStatus() {
    return status;
  }

  /**
   * Creative serving status. Read-only. This field should not be set in requests.
   * The value set may be {@code null}.
   */
  public Creative setStatus(String status) {
    this.status = status;
    return this;
  }

  /**
   * All vendor types for the ads that may be shown from this snippet.
   * The value returned may be {@code null}.
   */
  public java.util.List<Integer> getVendorType() {
    return vendorType;
  }

  /**
   * All vendor types for the ads that may be shown from this snippet.
   * The value set may be {@code null}.
   */
  public Creative setVendorType(java.util.List<Integer> vendorType) {
    this.vendorType = vendorType;
    return this;
  }

  /**
   * The url to fetch a video ad. If set, HTMLSnippet should not be set.
   * The value returned may be {@code null}.
   */
  public String getVideoURL() {
    return videoURL;
  }

  /**
   * The url to fetch a video ad. If set, HTMLSnippet should not be set.
   * The value set may be {@code null}.
   */
  public Creative setVideoURL(String videoURL) {
    this.videoURL = videoURL;
    return this;
  }

  /**
   * Ad width.
   * The value returned may be {@code null}.
   */
  public Integer getWidth() {
    return width;
  }

  /**
   * Ad width.
   * The value set may be {@code null}.
   */
  public Creative setWidth(Integer width) {
    this.width = width;
    return this;
  }

  /**
   * Model definition for CreativeDisapprovalReasons.
   */
  public static final class DisapprovalReasons extends GenericJson {

    /**
     * Additional details about the reason for disapproval.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<String> details;

    /**
     * The categorized reason for disapproval.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String reason;

    /**
     * Additional details about the reason for disapproval.
     * The value returned may be {@code null}.
     */
    public java.util.List<String> getDetails() {
      return details;
    }

    /**
     * Additional details about the reason for disapproval.
     * The value set may be {@code null}.
     */
    public DisapprovalReasons setDetails(java.util.List<String> details) {
      this.details = details;
      return this;
    }

    /**
     * The categorized reason for disapproval.
     * The value returned may be {@code null}.
     */
    public String getReason() {
      return reason;
    }

    /**
     * The categorized reason for disapproval.
     * The value set may be {@code null}.
     */
    public DisapprovalReasons setReason(String reason) {
      this.reason = reason;
      return this;
    }

  }

}
